KeyModifiers

Struct KeyModifiers 

pub struct KeyModifiers { /* private fields */ }
Represents key modifiers (shift, control, alt).

Implementations

Source

impl KeyModifiers

pub const SHIFT: KeyModifiers

pub const CONTROL: KeyModifiers

pub const ALT: KeyModifiers

pub const fn empty() -> KeyModifiers

Returns an empty set of flags

pub const fn all() -> KeyModifiers

Returns the set containing all flags.

pub const fn bits(&self) -> u8

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u8) -> Option<KeyModifiers>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u8) -> KeyModifiers

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u8) -> KeyModifiers

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: KeyModifiers) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: KeyModifiers) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: KeyModifiers)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: KeyModifiers)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: KeyModifiers)

Toggles the specified flags in-place.

pub fn set(&mut self, other: KeyModifiers, value: bool)

Inserts or removes the specified flags depending on the passed value.