pub struct KeyModifiers { /* private fields */ }Expand description
Represents key modifiers (shift, control, alt).
Implementations
Sourceimpl KeyModifiers
impl KeyModifiers
pub const SHIFT: KeyModifiers
pub const CONTROL: KeyModifiers
pub const ALT: KeyModifiers
Sourcepub const fn empty() -> KeyModifiers
pub const fn empty() -> KeyModifiers
Returns an empty set of flags
Sourcepub const fn all() -> KeyModifiers
pub const fn all() -> KeyModifiers
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u8) -> Option<KeyModifiers>
pub fn from_bits(bits: u8) -> Option<KeyModifiers>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u8) -> KeyModifiers
pub const fn from_bits_truncate(bits: u8) -> KeyModifiers
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u8) -> KeyModifiers
pub const unsafe fn from_bits_unchecked(bits: u8) -> KeyModifiers
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: KeyModifiers) -> bool
pub const fn intersects(&self, other: KeyModifiers) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: KeyModifiers) -> bool
pub const fn contains(&self, other: KeyModifiers) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: KeyModifiers)
pub fn insert(&mut self, other: KeyModifiers)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: KeyModifiers)
pub fn remove(&mut self, other: KeyModifiers)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: KeyModifiers)
pub fn toggle(&mut self, other: KeyModifiers)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: KeyModifiers, value: bool)
pub fn set(&mut self, other: KeyModifiers, value: bool)
Inserts or removes the specified flags depending on the passed value.